getReportRaw abstract method
Collects device trust signals as a raw map.
Platform implementations should return the six boolean signal keys and:
flags(non-negative int; optional for legacy implementations)rootedOrJailbroken(bool)emulator(bool)devModeEnabled(bool)adbEnabled(bool)fridaSuspected(bool)debuggerAttached(bool)details(Map<String, dynamic>)
DeviceTrustReport prefers flags when available and derives it from the
six legacy boolean keys otherwise.
Implementation
Future<Map<String, Object?>> getReportRaw();